"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSecurityState = exports.useSecurityActions = exports.SecurityContextProvider = exports.SecurityActionContext = void 0;

var _react = _interopRequireDefault(require("react"));

var _reducer = require("./reducer");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @packageDocumentation
 * @module SecurityContextProvider
 */

/** @ignore */
const StateContext = /*#__PURE__*/_react.default.createContext(null);
/** @ignore */


const DispatchContext = /*#__PURE__*/_react.default.createContext(null);
/**
 * A hook to get the security state (authenticated / not authenticated).
 *
 * NOTE: Must be used inside of a [[SecurityContextProvider]].
 * @category Hooks
 */


exports.SecurityActionContext = DispatchContext;

const useSecurityState = () => {
  const context = _react.default.useContext(StateContext);

  if (context === null) {
    throw new Error('useSecurityState must be used within an SecurityContextProvider');
  }

  return context;
};
/**
 * A hook to get the security actions (on authenticated / on not authenticated).
 *
 * NOTE: Must be used inside of a [[SecurityContextProvider]].
 * @category Hooks
 */


exports.useSecurityState = useSecurityState;

const useSecurityActions = () => {
  const context = _react.default.useContext(DispatchContext);

  if (context === null) {
    throw new Error('useSecurityActions must be used within an SecurityContextProvider');
  }

  return context;
};
/**
 *  Provides a wrapper for the security state and security actions.
 *
 *  @public
 *  @category Component
 */


exports.useSecurityActions = useSecurityActions;

const SecurityContextProvider = props => {
  const initialContextState = {
    userId: undefined,
    email: undefined,
    rememberMeDetails: {
      email: undefined,
      rememberMe: undefined
    },
    isAuthenticatedUser: false,
    isLoading: true,
    isSignOut: false,
    isShowingChangePassword: false
  };

  const [state, dispatch] = _react.default.useReducer(_reducer.reducer, initialContextState); // Function will not change for children (dispatch does not need to be a dependency)


  const onUserNotAuthenticated = _react.default.useCallback(function () {
    let clearRememberMe = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
    let overrideRememberMeEmail = arguments.length > 1 ? arguments[1] : undefined;
    dispatch({
      type: 'userNotAuthenticated',
      payload: {
        clearRememberMe: clearRememberMe,
        overrideRememberMeEmail: overrideRememberMeEmail
      }
    });
  }, []);

  const showChangePassword = _react.default.useCallback(() => {
    dispatch({
      type: 'showChangePassword'
    });
  }, []);

  const hideChangePassword = _react.default.useCallback(() => {
    dispatch({
      type: 'hideChangePassword'
    });
  }, []); // Function will not change for children (dispatch does not need to be a dependency)


  const onUserAuthenticated = _react.default.useCallback(onUserAuthenticatedArgs => {
    dispatch({
      type: 'userAuthenticated',
      payload: onUserAuthenticatedArgs
    });
  }, []); // Context value will not change unless a sub function is changed


  const memoizedAuthHelper = _react.default.useMemo(() => {
    const authHelper = {
      onUserAuthenticated,
      onUserNotAuthenticated,
      showChangePassword,
      hideChangePassword
    };
    return authHelper;
  }, [onUserAuthenticated, onUserNotAuthenticated, showChangePassword, hideChangePassword]);

  return /*#__PURE__*/_react.default.createElement(StateContext.Provider, {
    value: state
  }, /*#__PURE__*/_react.default.createElement(DispatchContext.Provider, {
    value: memoizedAuthHelper
  }, props.children));
};

exports.SecurityContextProvider = SecurityContextProvider;
//# sourceMappingURL=SecurityContextProvider.js.map